@@ -9,7 +9,7 @@
 #include "virtual_output.h"
 #include "virtual_backend.h"
 
-#include "renderloop_p.h"
+#include "core/renderloop_p.h"
 #include "softwarevsyncmonitor.h"
 
 namespace KWin
@@ -18,10 +18,10 @@ namespace KWin
 VirtualOutput::VirtualOutput(VirtualBackend *parent)
     : Output(parent)
     , m_backend(parent)
-    , m_renderLoop(new RenderLoop(this))
-    , m_vsyncMonitor(SoftwareVsyncMonitor::create(this))
+    , m_renderLoop(std::make_unique<RenderLoop>())
+    , m_vsyncMonitor(SoftwareVsyncMonitor::create())
 {
-    connect(m_vsyncMonitor, &VsyncMonitor::vblankOccurred, this, &VirtualOutput::vblank);
+    connect(m_vsyncMonitor.get(), &VsyncMonitor::vblankOccurred, this, &VirtualOutput::vblank);
 
     static int identifier = -1;
     m_identifier = ++identifier;
@@ -36,12 +36,12 @@ VirtualOutput::~VirtualOutput()
 
 RenderLoop *VirtualOutput::renderLoop() const
 {
-    return m_renderLoop;
+    return m_renderLoop.get();
 }
 
 SoftwareVsyncMonitor *VirtualOutput::vsyncMonitor() const
 {
-    return m_vsyncMonitor;
+    return m_vsyncMonitor.get();
 }
 
 void VirtualOutput::init(const QPoint &logicalPosition, const QSize &pixelSize)
@@ -55,20 +55,34 @@ void VirtualOutput::init(const QPoint &logicalPosition, const QSize &pixelSize)
 
 void VirtualOutput::setGeometry(const QRect &geo)
 {
-    auto mode = QSharedPointer<OutputMode>::create(geo.size(), m_vsyncMonitor->refreshRate());
-    setModesInternal({mode}, mode);
-    moveTo(geo.topLeft());
+    auto mode = std::make_shared<OutputMode>(geo.size(), m_vsyncMonitor->refreshRate());
+
+    State next = m_state;
+    next.modes = {mode};
+    next.currentMode = mode;
+    next.position = geo.topLeft();
+
+    setState(next);
+}
+
+void VirtualOutput::updateScale(qreal scale)
+{
+    State next = m_state;
+    next.scale = scale;
+    setState(next);
+}
+
+void VirtualOutput::updateEnabled(bool enabled)
+{
+    State next = m_state;
+    next.enabled = enabled;
+    setState(next);
 }
 
 void VirtualOutput::vblank(std::chrono::nanoseconds timestamp)
 {
-    RenderLoopPrivate *renderLoopPrivate = RenderLoopPrivate::get(m_renderLoop);
+    RenderLoopPrivate *renderLoopPrivate = RenderLoopPrivate::get(m_renderLoop.get());
     renderLoopPrivate->notifyFrameCompleted(timestamp);
 }
 
-void VirtualOutput::updateEnablement(bool enable)
-{
-    m_backend->enableOutput(this, enable);
-}
-
 }
