@@ -8,13 +8,14 @@
 */
 #include "debug_console.h"
 #include "composite.h"
+#include "core/inputdevice.h"
 #include "input_event.h"
-#include "inputdevice.h"
 #include "internalwindow.h"
 #include "keyboard_input.h"
 #include "main.h"
 #include "scene.h"
 #include "unmanaged.h"
+#include "utils/filedescriptor.h"
 #include "utils/subsurfacemonitor.h"
 #include "wayland/abstract_data_source.h"
 #include "wayland/clientconnection.h"
@@ -45,6 +46,7 @@
 #include <QMetaType>
 #include <QMouseEvent>
 #include <QScopeGuard>
+#include <QSortFilterProxyModel>
 #include <QtConcurrentRun>
 
 #include <wayland-server-core.h>
@@ -512,51 +514,55 @@ void DebugConsoleFilter::tabletToolEvent(TabletEvent *event)
     m_textEdit->ensureCursorVisible();
 }
 
-void DebugConsoleFilter::tabletToolButtonEvent(uint button, bool pressed, const TabletToolId &tabletToolId)
+void DebugConsoleFilter::tabletToolButtonEvent(uint button, bool pressed, const TabletToolId &tabletToolId, uint time)
 {
     QString text = s_hr + s_tableStart + tableHeaderRow(i18n("Tablet Tool Button"))
         + tableRow(i18n("Button"), button)
         + tableRow(i18n("Pressed"), pressed)
         + tableRow(i18n("Tablet"), qHash(tabletToolId.m_deviceGroupData))
+        + timestampRow(time)
         + s_tableEnd;
 
     m_textEdit->insertHtml(text);
     m_textEdit->ensureCursorVisible();
 }
 
-void DebugConsoleFilter::tabletPadButtonEvent(uint button, bool pressed, const TabletPadId &tabletPadId)
+void DebugConsoleFilter::tabletPadButtonEvent(uint button, bool pressed, const TabletPadId &tabletPadId, uint time)
 {
     QString text = s_hr + s_tableStart
         + tableHeaderRow(i18n("Tablet Pad Button"))
         + tableRow(i18n("Button"), button)
         + tableRow(i18n("Pressed"), pressed)
         + tableRow(i18n("Tablet"), qHash(tabletPadId.data))
+        + timestampRow(time)
         + s_tableEnd;
 
     m_textEdit->insertHtml(text);
     m_textEdit->ensureCursorVisible();
 }
 
-void DebugConsoleFilter::tabletPadStripEvent(int number, int position, bool isFinger, const TabletPadId &tabletPadId)
+void DebugConsoleFilter::tabletPadStripEvent(int number, int position, bool isFinger, const TabletPadId &tabletPadId, uint time)
 {
     QString text = s_hr + s_tableStart + tableHeaderRow(i18n("Tablet Pad Strip"))
         + tableRow(i18n("Number"), number)
         + tableRow(i18n("Position"), position)
         + tableRow(i18n("isFinger"), isFinger)
         + tableRow(i18n("Tablet"), qHash(tabletPadId.data))
+        + timestampRow(time)
         + s_tableEnd;
 
     m_textEdit->insertHtml(text);
     m_textEdit->ensureCursorVisible();
 }
 
-void DebugConsoleFilter::tabletPadRingEvent(int number, int position, bool isFinger, const TabletPadId &tabletPadId)
+void DebugConsoleFilter::tabletPadRingEvent(int number, int position, bool isFinger, const TabletPadId &tabletPadId, uint time)
 {
     QString text = s_hr + s_tableStart + tableHeaderRow(i18n("Tablet Pad Ring"))
         + tableRow(i18n("Number"), number)
         + tableRow(i18n("Position"), position)
         + tableRow(i18n("isFinger"), isFinger)
         + tableRow(i18n("Tablet"), qHash(tabletPadId.data))
+        + timestampRow(time)
         + s_tableEnd;
 
     m_textEdit->insertHtml(text);
@@ -591,8 +597,15 @@ DebugConsole::DebugConsole()
 {
     setAttribute(Qt::WA_ShowWithoutActivating);
     m_ui->setupUi(this);
+
+    auto windowsModel = new DebugConsoleModel(this);
+    QSortFilterProxyModel *proxyWindowsModel = new QSortFilterProxyModel(this);
+    proxyWindowsModel->setSourceModel(windowsModel);
+    m_ui->windowsView->setModel(proxyWindowsModel);
+    m_ui->windowsView->sortByColumn(0, Qt::AscendingOrder);
+    m_ui->windowsView->header()->setSortIndicatorShown(true);
     m_ui->windowsView->setItemDelegate(new DebugConsoleDelegate(this));
-    m_ui->windowsView->setModel(new DebugConsoleModel(this));
+
     m_ui->surfacesView->setModel(new SurfaceTreeModel(this));
     m_ui->clipboardContent->setModel(new DataSourceModel(this));
     m_ui->primaryContent->setModel(new DataSourceModel(this));
@@ -611,9 +624,9 @@ DebugConsole::DebugConsole()
     connect(m_ui->quitButton, &QAbstractButton::clicked, this, &DebugConsole::deleteLater);
     connect(m_ui->tabWidget, &QTabWidget::currentChanged, this, [this](int index) {
         // delay creation of input event filter until the tab is selected
-        if (index == 2 && m_inputFilter.isNull()) {
+        if (index == 2 && !m_inputFilter) {
             m_inputFilter.reset(new DebugConsoleFilter(m_ui->inputTextEdit));
-            input()->installInputEventSpy(m_inputFilter.data());
+            input()->installInputEventSpy(m_inputFilter.get());
         }
         if (index == 5) {
             updateKeyboardTab();
@@ -760,6 +773,10 @@ QString DebugConsoleDelegate::displayText(const QVariant &value, const QLocale &
         const QRect r = value.toRect();
         return QStringLiteral("%1,%2 %3x%4").arg(r.x()).arg(r.y()).arg(r.width()).arg(r.height());
     }
+    case QMetaType::QRectF: {
+        const QRectF r = value.toRectF();
+        return QStringLiteral("%1,%2 %3x%4").arg(r.x()).arg(r.y()).arg(r.width()).arg(r.height());
+    }
     default:
         if (value.userType() == qMetaTypeId<KWaylandServer::SurfaceInterface *>()) {
             if (auto s = value.value<KWaylandServer::SurfaceInterface *>()) {
@@ -1157,6 +1174,8 @@ QVariant DebugConsoleModel::propertyData(QObject *object, const QModelIndex &ind
                 return QStringLiteral("NET::OnScreenDisplay");
             case NET::CriticalNotification:
                 return QStringLiteral("NET::CriticalNotification");
+            case NET::AppletPopup:
+                return QStringLiteral("NET::AppletPopup");
             case NET::Unknown:
             default:
                 return QStringLiteral("NET::Unknown");
@@ -1590,6 +1609,7 @@ QModelIndex DataSourceModel::index(int row, int column, const QModelIndex &paren
 
 QModelIndex DataSourceModel::parent(const QModelIndex &child) const
 {
+    Q_UNUSED(child)
     return QModelIndex();
 }
 
@@ -1636,9 +1656,7 @@ static QByteArray readData(int fd)
     pollfd pfd;
     pfd.fd = fd;
     pfd.events = POLLIN;
-    auto closeFd = qScopeGuard([fd] {
-        close(fd);
-    });
+    FileDescriptor closeFd{fd};
     QByteArray data;
     while (true) {
         const int ready = poll(&pfd, 1, 1000);
