@@ -7,15 +7,19 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "abstract_egl_backend.h"
-#include "egl_dmabuf.h"
 #include "composite.h"
+#include "core/output.h"
+#include "core/platform.h"
+#include "dmabuftexture.h"
+#include "egl_dmabuf.h"
 #include "options.h"
-#include "platform.h"
+#include "utils/common.h"
 #include "utils/egl_context_attribute_builder.h"
+#include "wayland/display.h"
 #include "wayland_server.h"
-#include "abstract_wayland_output.h"
-#include <KWaylandServer/display.h>
 // kwin libs
+#include <kwineglimagetexture.h>
+#include <kwineglutils_p.h>
 #include <kwinglplatform.h>
 #include <kwinglutils.h>
 // Qt
@@ -23,6 +27,8 @@
 
 #include <memory>
 
+#include <drm_fourcc.h>
+
 namespace KWin
 {
 
@@ -36,14 +42,9 @@ static bool isOpenGLES_helper()
     return QOpenGLContext::openGLModuleType() == QOpenGLContext::LibGLES;
 }
 
-AbstractEglBackend *AbstractEglBackend::s_primaryBackend = nullptr;
-
 AbstractEglBackend::AbstractEglBackend(dev_t deviceId)
     : m_deviceId(deviceId)
 {
-    if (s_primaryBackend == nullptr) {
-        setPrimaryBackend(this);
-    }
     connect(Compositor::self(), &Compositor::aboutToDestroy, this, &AbstractEglBackend::teardown);
 }
 
@@ -85,12 +86,10 @@ void AbstractEglBackend::teardown()
 void AbstractEglBackend::cleanup()
 {
     cleanupSurfaces();
-    if (isPrimary()) {
-        cleanupGL();
-        doneCurrent();
-        eglDestroyContext(m_display, m_context);
-        eglReleaseThread();
-    }
+    cleanupGL();
+    doneCurrent();
+    eglDestroyContext(m_display, m_context);
+    eglReleaseThread();
 }
 
 void AbstractEglBackend::cleanupSurfaces()
@@ -142,7 +141,7 @@ bool AbstractEglBackend::initEglAPI()
 }
 
 typedef void (*eglFuncPtr)();
-static eglFuncPtr getProcAddress(const char* name)
+static eglFuncPtr getProcAddress(const char *name)
 {
     return eglGetProcAddress(name);
 }
@@ -152,8 +151,9 @@ void AbstractEglBackend::initKWinGL()
     GLPlatform *glPlatform = GLPlatform::instance();
     glPlatform->detect(EglPlatformInterface);
     options->setGlPreferBufferSwap(options->glPreferBufferSwap()); // resolve autosetting
-    if (options->glPreferBufferSwap() == Options::AutoSwapStrategy)
+    if (options->glPreferBufferSwap() == Options::AutoSwapStrategy) {
         options->setGlPreferBufferSwap('e'); // for unknown drivers - should not happen
+    }
     glPlatform->printResults();
     initGL(&getProcAddress);
 }
@@ -206,12 +206,12 @@ void AbstractEglBackend::initWayland()
 void AbstractEglBackend::initClientExtensions()
 {
     // Get the list of client extensions
-    const char* clientExtensionsCString = eglQueryString(EGL_NO_DISPLAY, EGL_EXTENSIONS);
+    const char *clientExtensionsCString = eglQueryString(EGL_NO_DISPLAY, EGL_EXTENSIONS);
     const QByteArray clientExtensionsString = QByteArray::fromRawData(clientExtensionsCString, qstrlen(clientExtensionsCString));
     if (clientExtensionsString.isEmpty()) {
         // If eglQueryString() returned NULL, the implementation doesn't support
         // EGL_EXT_client_extensions. Expect an EGL_BAD_DISPLAY error.
-        (void) eglGetError();
+        (void)eglGetError();
     }
 
     m_clientExtensions = clientExtensionsString.split(' ');
@@ -358,11 +358,10 @@ EGLContext AbstractEglBackend::createContextInternal(EGLContext sharedContext)
     return ctx;
 }
 
-void AbstractEglBackend::setEglDisplay(const EGLDisplay &display) {
+void AbstractEglBackend::setEglDisplay(const EGLDisplay &display)
+{
     m_display = display;
-    if (isPrimary()) {
-        kwinApp()->platform()->setSceneEglDisplay(display);
-    }
+    kwinApp()->platform()->setSceneEglDisplay(display);
 }
 
 void AbstractEglBackend::setConfig(const EGLConfig &config)
@@ -375,14 +374,11 @@ void AbstractEglBackend::setSurface(const EGLSurface &surface)
     m_surface = surface;
 }
 
-QSharedPointer<GLTexture> AbstractEglBackend::textureForOutput(AbstractOutput *requestedOutput) const
+std::shared_ptr<GLTexture> AbstractEglBackend::textureForOutput(Output *requestedOutput) const
 {
-    QSharedPointer<GLTexture> texture(new GLTexture(GL_RGBA8, requestedOutput->pixelSize()));
-    GLRenderTarget renderTarget(*texture);
-
-    const QRect geo = requestedOutput->geometry();
-    QRect invGeo(geo.left(), geo.bottom(), geo.width(), -geo.height());
-    renderTarget.blitFromFramebuffer(invGeo);
+    std::shared_ptr<GLTexture> texture(new GLTexture(GL_RGBA8, requestedOutput->pixelSize()));
+    GLFramebuffer renderTarget(texture.get());
+    renderTarget.blitFromFramebuffer(QRect(0, texture->height(), texture->width(), -texture->height()));
     return texture;
 }
 
@@ -401,4 +397,76 @@ EglDmabuf *AbstractEglBackend::dmabuf() const
     return m_dmaBuf;
 }
 
+EGLImageKHR AbstractEglBackend::importDmaBufAsImage(const DmaBufAttributes &dmabuf) const
+{
+    QVector<EGLint> attribs;
+    attribs.reserve(6 + dmabuf.planeCount * 10 + 1);
+
+    attribs
+        << EGL_WIDTH << dmabuf.width
+        << EGL_HEIGHT << dmabuf.height
+        << EGL_LINUX_DRM_FOURCC_EXT << dmabuf.format;
+
+    attribs
+        << EGL_DMA_BUF_PLANE0_FD_EXT << dmabuf.fd[0].get()
+        << EGL_DMA_BUF_PLANE0_OFFSET_EXT << dmabuf.offset[0]
+        << EGL_DMA_BUF_PLANE0_PITCH_EXT << dmabuf.pitch[0];
+    if (dmabuf.modifier != DRM_FORMAT_MOD_INVALID) {
+        attribs
+            << EGL_DMA_BUF_PLANE0_MODIFIER_LO_EXT << EGLint(dmabuf.modifier & 0xffffffff)
+            << EGL_DMA_BUF_PLANE0_MODIFIER_HI_EXT << EGLint(dmabuf.modifier >> 32);
+    }
+
+    if (dmabuf.planeCount > 1) {
+        attribs
+            << EGL_DMA_BUF_PLANE1_FD_EXT << dmabuf.fd[1].get()
+            << EGL_DMA_BUF_PLANE1_OFFSET_EXT << dmabuf.offset[1]
+            << EGL_DMA_BUF_PLANE1_PITCH_EXT << dmabuf.pitch[1];
+        if (dmabuf.modifier != DRM_FORMAT_MOD_INVALID) {
+            attribs
+                << EGL_DMA_BUF_PLANE1_MODIFIER_LO_EXT << EGLint(dmabuf.modifier & 0xffffffff)
+                << EGL_DMA_BUF_PLANE1_MODIFIER_HI_EXT << EGLint(dmabuf.modifier >> 32);
+        }
+    }
+
+    if (dmabuf.planeCount > 2) {
+        attribs
+            << EGL_DMA_BUF_PLANE2_FD_EXT << dmabuf.fd[2].get()
+            << EGL_DMA_BUF_PLANE2_OFFSET_EXT << dmabuf.offset[2]
+            << EGL_DMA_BUF_PLANE2_PITCH_EXT << dmabuf.pitch[2];
+        if (dmabuf.modifier != DRM_FORMAT_MOD_INVALID) {
+            attribs
+                << EGL_DMA_BUF_PLANE2_MODIFIER_LO_EXT << EGLint(dmabuf.modifier & 0xffffffff)
+                << EGL_DMA_BUF_PLANE2_MODIFIER_HI_EXT << EGLint(dmabuf.modifier >> 32);
+        }
+    }
+
+    if (dmabuf.planeCount > 3) {
+        attribs
+            << EGL_DMA_BUF_PLANE3_FD_EXT << dmabuf.fd[3].get()
+            << EGL_DMA_BUF_PLANE3_OFFSET_EXT << dmabuf.offset[3]
+            << EGL_DMA_BUF_PLANE3_PITCH_EXT << dmabuf.pitch[3];
+        if (dmabuf.modifier != DRM_FORMAT_MOD_INVALID) {
+            attribs
+                << EGL_DMA_BUF_PLANE3_MODIFIER_LO_EXT << EGLint(dmabuf.modifier & 0xffffffff)
+                << EGL_DMA_BUF_PLANE3_MODIFIER_HI_EXT << EGLint(dmabuf.modifier >> 32);
+        }
+    }
+
+    attribs << EGL_NONE;
+
+    return eglCreateImageKHR(m_display, EGL_NO_CONTEXT, EGL_LINUX_DMA_BUF_EXT, nullptr, attribs.data());
+}
+
+std::shared_ptr<GLTexture> AbstractEglBackend::importDmaBufAsTexture(const DmaBufAttributes &attributes) const
+{
+    EGLImageKHR image = importDmaBufAsImage(attributes);
+    if (image != EGL_NO_IMAGE_KHR) {
+        return std::make_shared<EGLImageTexture>(eglDisplay(), image, GL_RGBA8, QSize(attributes.width, attributes.height));
+    } else {
+        qCWarning(KWIN_OPENGL) << "Failed to record frame: Error creating EGLImageKHR - " << getEglErrorString();
+        return nullptr;
+    }
+}
+
 }
