@@ -55,7 +55,8 @@ static bool screenContainsPos(const QPointF &pos)
 {
     const auto outputs = workspace()->outputs();
     for (const Output *output : outputs) {
-        if (output->geometry().contains(pos.toPoint())) {
+        if (output->geometry().contains(QPoint(std::floor(pos.x()),
+                                               std::floor(pos.y())))) {
             return true;
         }
     }
